// Copyright (c) 2017-2022 The MathJax Consortium
// SPDX-License-Identifier: Apache-2.0
// Code generated from MathJax 3.2.2 ts/core/MmlTree/OperatorDictionary.ts;
// DO NOT EDIT.

package tex

type mjOperatorProperty struct {
	Name  string
	Value any
}

type mjOperatorProperties []mjOperatorProperty

type mjOperatorDefinition struct {
	Lspace     int
	Rspace     int
	TexClass   int
	Properties mjOperatorProperties
}

type mjOperatorNamedDefinition struct {
	Name       string
	Definition mjOperatorDefinition
	SourceLine int
	Reference  string
}

type mjOperatorRange struct {
	First      int
	Last       int
	TexClass   int
	Kind       string
	Variant    string
	HasVariant bool
	SourceLine int
}

type mjOperatorSpacing struct {
	TexClass   int
	Lspace     int
	Rspace     int
	SourceLine int
}

type mjOperatorDictionaryEntry struct {
	Operator   string
	Definition mjOperatorDefinition
	SourceLine int
	Reference  string
}

type mjOperatorDictionaryMutation struct {
	Form               string
	Operator           string
	Definition         mjOperatorDefinition
	SourceLine         int
	Reference          string
	HadPrevious        bool
	PreviousDefinition mjOperatorDefinition
	PreviousSourceLine int
	PreviousReference  string
}

var mjOperatorDefinitions = []mjOperatorNamedDefinition{
	{Name: "ORD", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 50, Reference: "OPDEF"},
	{Name: "ORD11", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 0}, SourceLine: 51, Reference: "OPDEF"},
	{Name: "ORD21", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 1, TexClass: 0}, SourceLine: 52, Reference: "OPDEF"},
	{Name: "ORD02", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 2, TexClass: 0}, SourceLine: 53, Reference: "OPDEF"},
	{Name: "ORD55", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 0}, SourceLine: 54, Reference: "OPDEF"},
	{Name: "NONE", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: -1}, SourceLine: 55, Reference: "OPDEF"},
	{Name: "OP", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 56, Reference: "OPDEF"},
	{Name: "OPFIXED", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}}}, SourceLine: 57, Reference: "OPDEF"},
	{Name: "INTEGRAL", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 58, Reference: "OPDEF"},
	{Name: "INTEGRAL2", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 59, Reference: "OPDEF"},
	{Name: "BIN3", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 60, Reference: "OPDEF"},
	{Name: "BIN4", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 61, Reference: "OPDEF"},
	{Name: "BIN01", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 2}, SourceLine: 62, Reference: "OPDEF"},
	{Name: "BIN5", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 2}, SourceLine: 63, Reference: "OPDEF"},
	{Name: "TALLBIN", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 64, Reference: "OPDEF"},
	{Name: "BINOP", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}}}, SourceLine: 65, Reference: "OPDEF"},
	{Name: "REL", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 66, Reference: "OPDEF"},
	{Name: "REL1", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 67, Reference: "OPDEF"},
	{Name: "REL4", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 3}, SourceLine: 68, Reference: "OPDEF"},
	{Name: "RELSTRETCH", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 69, Reference: "OPDEF"},
	{Name: "RELACCENT", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 70, Reference: "OPDEF"},
	{Name: "WIDEREL", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 71, Reference: "OPDEF"},
	{Name: "OPEN", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 72, Reference: "OPDEF"},
	{Name: "CLOSE", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 73, Reference: "OPDEF"},
	{Name: "INNER", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 7}, SourceLine: 74, Reference: "OPDEF"},
	{Name: "PUNCT", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 3, TexClass: 6}, SourceLine: 75, Reference: "OPDEF"},
	{Name: "ACCENT", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 76, Reference: "OPDEF"},
	{Name: "WIDEACCENT", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 77, Reference: "OPDEF"},
}

var mjOperatorRanges = []mjOperatorRange{
	{First: 32, Last: 127, TexClass: 3, Kind: "mo", SourceLine: 84},
	{First: 160, Last: 191, TexClass: 0, Kind: "mo", SourceLine: 85},
	{First: 192, Last: 591, TexClass: 0, Kind: "mi", SourceLine: 86},
	{First: 688, Last: 879, TexClass: 0, Kind: "mo", SourceLine: 87},
	{First: 880, Last: 6688, TexClass: 0, Kind: "mi", SourceLine: 88},
	{First: 6832, Last: 6911, TexClass: 0, Kind: "mo", SourceLine: 89},
	{First: 6912, Last: 7615, TexClass: 0, Kind: "mi", SourceLine: 90},
	{First: 7616, Last: 7679, TexClass: 0, Kind: "mo", SourceLine: 91},
	{First: 7680, Last: 8191, TexClass: 0, Kind: "mi", SourceLine: 92},
	{First: 8192, Last: 8303, TexClass: 0, Kind: "mo", SourceLine: 93},
	{First: 8304, Last: 8351, TexClass: 0, Kind: "mo", SourceLine: 94},
	{First: 8448, Last: 8527, TexClass: 0, Kind: "mi", SourceLine: 95},
	{First: 8528, Last: 8591, TexClass: 0, Kind: "mn", SourceLine: 96},
	{First: 8592, Last: 8703, TexClass: 3, Kind: "mo", SourceLine: 97},
	{First: 8704, Last: 8959, TexClass: 2, Kind: "mo", SourceLine: 98},
	{First: 8960, Last: 9215, TexClass: 0, Kind: "mo", SourceLine: 99},
	{First: 9312, Last: 9471, TexClass: 0, Kind: "mn", SourceLine: 100},
	{First: 9472, Last: 10223, TexClass: 0, Kind: "mo", SourceLine: 101},
	{First: 10224, Last: 10239, TexClass: 3, Kind: "mo", SourceLine: 102},
	{First: 10240, Last: 10495, TexClass: 0, Kind: "mtext", SourceLine: 103},
	{First: 10496, Last: 10623, TexClass: 3, Kind: "mo", SourceLine: 104},
	{First: 10624, Last: 10751, TexClass: 0, Kind: "mo", SourceLine: 105},
	{First: 10752, Last: 11007, TexClass: 2, Kind: "mo", SourceLine: 106},
	{First: 11008, Last: 11055, TexClass: 0, Kind: "mo", SourceLine: 107},
	{First: 11056, Last: 11087, TexClass: 3, Kind: "mo", SourceLine: 108},
	{First: 11088, Last: 11263, TexClass: 0, Kind: "mo", SourceLine: 109},
	{First: 11264, Last: 11744, TexClass: 0, Kind: "mi", SourceLine: 110},
	{First: 11776, Last: 11903, TexClass: 0, Kind: "mo", SourceLine: 111},
	{First: 11904, Last: 12255, TexClass: 0, Kind: "mi", SourceLine: 112, Variant: "normal", HasVariant: true},
	{First: 12272, Last: 12351, TexClass: 0, Kind: "mo", SourceLine: 113},
	{First: 12352, Last: 42143, TexClass: 0, Kind: "mi", SourceLine: 114, Variant: "normal", HasVariant: true},
	{First: 42192, Last: 43055, TexClass: 0, Kind: "mi", SourceLine: 115},
	{First: 43056, Last: 43071, TexClass: 0, Kind: "mn", SourceLine: 116},
	{First: 43072, Last: 55295, TexClass: 0, Kind: "mi", SourceLine: 117},
	{First: 63744, Last: 64255, TexClass: 0, Kind: "mi", SourceLine: 118, Variant: "normal", HasVariant: true},
	{First: 64256, Last: 65023, TexClass: 0, Kind: "mi", SourceLine: 119},
	{First: 65024, Last: 65135, TexClass: 0, Kind: "mo", SourceLine: 120},
	{First: 65136, Last: 65791, TexClass: 0, Kind: "mi", SourceLine: 121},
	{First: 65792, Last: 65935, TexClass: 0, Kind: "mn", SourceLine: 122},
	{First: 65936, Last: 74751, TexClass: 0, Kind: "mi", SourceLine: 123, Variant: "normal", HasVariant: true},
	{First: 74752, Last: 74879, TexClass: 0, Kind: "mn", SourceLine: 124},
	{First: 74880, Last: 113823, TexClass: 0, Kind: "mi", SourceLine: 125, Variant: "normal", HasVariant: true},
	{First: 113824, Last: 119391, TexClass: 0, Kind: "mo", SourceLine: 126},
	{First: 119648, Last: 119679, TexClass: 0, Kind: "mn", SourceLine: 127},
	{First: 119808, Last: 120781, TexClass: 0, Kind: "mi", SourceLine: 128},
	{First: 120782, Last: 120831, TexClass: 0, Kind: "mn", SourceLine: 129},
	{First: 122624, Last: 129023, TexClass: 0, Kind: "mo", SourceLine: 130},
	{First: 129024, Last: 129279, TexClass: 3, Kind: "mo", SourceLine: 131},
	{First: 129280, Last: 129535, TexClass: 0, Kind: "mo", SourceLine: 132},
	{First: 131072, Last: 195103, TexClass: 0, Kind: "mi", SourceLine: 133, Variant: "normnal", HasVariant: true},
}

var mjOperatorMMLSpacing = []mjOperatorSpacing{
	{TexClass: 0, Lspace: 0, Rspace: 0, SourceLine: 159},
	{TexClass: 1, Lspace: 1, Rspace: 2, SourceLine: 160},
	{TexClass: 2, Lspace: 3, Rspace: 3, SourceLine: 161},
	{TexClass: 3, Lspace: 4, Rspace: 4, SourceLine: 162},
	{TexClass: 4, Lspace: 0, Rspace: 0, SourceLine: 163},
	{TexClass: 5, Lspace: 0, Rspace: 0, SourceLine: 164},
	{TexClass: 6, Lspace: 0, Rspace: 3, SourceLine: 165},
}

var mjOperatorDictionaryPrefix = []mjOperatorDictionaryEntry{
	{Operator: "(", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 173, Reference: "MO.OPEN"},
	{Operator: "+", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 2}, SourceLine: 174, Reference: "MO.BIN01"},
	{Operator: "-", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 2}, SourceLine: 175, Reference: "MO.BIN01"},
	{Operator: "[", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 176, Reference: "MO.OPEN"},
	{Operator: "{", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 177, Reference: "MO.OPEN"},
	{Operator: "|", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 178, Reference: "MO.OPEN"},
	{Operator: "||", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 2, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 179, Reference: ""},
	{Operator: "|||", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 180, Reference: ""},
	{Operator: "¬", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 1, TexClass: 0}, SourceLine: 181, Reference: "MO.ORD21"},
	{Operator: "±", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 2}, SourceLine: 182, Reference: "MO.BIN01"},
	{Operator: "‖", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 183, Reference: ""},
	{Operator: "‘", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}}}, SourceLine: 184, Reference: ""},
	{Operator: "“", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}}}, SourceLine: 185, Reference: ""},
	{Operator: "ⅅ", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 1, TexClass: 0}, SourceLine: 186, Reference: "MO.ORD21"},
	{Operator: "ⅆ", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 0, TexClass: 0}, SourceLine: 187, Reference: "OPDEF"},
	{Operator: "∀", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 1, TexClass: 0}, SourceLine: 188, Reference: "MO.ORD21"},
	{Operator: "∂", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 1, TexClass: 0}, SourceLine: 189, Reference: "MO.ORD21"},
	{Operator: "∃", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 1, TexClass: 0}, SourceLine: 190, Reference: "MO.ORD21"},
	{Operator: "∄", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 1, TexClass: 0}, SourceLine: 191, Reference: "MO.ORD21"},
	{Operator: "∇", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 1, TexClass: 0}, SourceLine: 192, Reference: "MO.ORD21"},
	{Operator: "∏", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 193, Reference: "MO.OP"},
	{Operator: "∐", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 194, Reference: "MO.OP"},
	{Operator: "∑", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 195, Reference: "MO.OP"},
	{Operator: "−", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 2}, SourceLine: 196, Reference: "MO.BIN01"},
	{Operator: "∓", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 2}, SourceLine: 197, Reference: "MO.BIN01"},
	{Operator: "√", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 0, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 198, Reference: ""},
	{Operator: "∛", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 0}, SourceLine: 199, Reference: "MO.ORD11"},
	{Operator: "∜", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 0}, SourceLine: 200, Reference: "MO.ORD11"},
	{Operator: "∠", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 201, Reference: "MO.ORD"},
	{Operator: "∡", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 202, Reference: "MO.ORD"},
	{Operator: "∢", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 203, Reference: "MO.ORD"},
	{Operator: "∫", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 204, Reference: "MO.INTEGRAL"},
	{Operator: "∬", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 205, Reference: "MO.INTEGRAL"},
	{Operator: "∭", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 206, Reference: "MO.INTEGRAL"},
	{Operator: "∮", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 207, Reference: "MO.INTEGRAL"},
	{Operator: "∯", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 208, Reference: "MO.INTEGRAL"},
	{Operator: "∰", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 209, Reference: "MO.INTEGRAL"},
	{Operator: "∱", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 210, Reference: "MO.INTEGRAL"},
	{Operator: "∲", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 211, Reference: "MO.INTEGRAL"},
	{Operator: "∳", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 212, Reference: "MO.INTEGRAL"},
	{Operator: "⋀", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 213, Reference: "MO.OP"},
	{Operator: "⋁", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 214, Reference: "MO.OP"},
	{Operator: "⋂", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 215, Reference: "MO.OP"},
	{Operator: "⋃", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 216, Reference: "MO.OP"},
	{Operator: "⌈", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 217, Reference: "MO.OPEN"},
	{Operator: "⌊", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 218, Reference: "MO.OPEN"},
	{Operator: "〈", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 219, Reference: "MO.OPEN"},
	{Operator: "❲", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 220, Reference: "MO.OPEN"},
	{Operator: "⟦", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 221, Reference: "MO.OPEN"},
	{Operator: "⟨", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 222, Reference: "MO.OPEN"},
	{Operator: "⟪", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 223, Reference: "MO.OPEN"},
	{Operator: "⟬", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 224, Reference: "MO.OPEN"},
	{Operator: "⟮", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 225, Reference: "MO.OPEN"},
	{Operator: "⦀", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 226, Reference: ""},
	{Operator: "⦃", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 227, Reference: "MO.OPEN"},
	{Operator: "⦅", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 228, Reference: "MO.OPEN"},
	{Operator: "⦇", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 229, Reference: "MO.OPEN"},
	{Operator: "⦉", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 230, Reference: "MO.OPEN"},
	{Operator: "⦋", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 231, Reference: "MO.OPEN"},
	{Operator: "⦍", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 232, Reference: "MO.OPEN"},
	{Operator: "⦏", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 233, Reference: "MO.OPEN"},
	{Operator: "⦑", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 234, Reference: "MO.OPEN"},
	{Operator: "⦓", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 235, Reference: "MO.OPEN"},
	{Operator: "⦕", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 236, Reference: "MO.OPEN"},
	{Operator: "⦗", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 237, Reference: "MO.OPEN"},
	{Operator: "⧼", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 238, Reference: "MO.OPEN"},
	{Operator: "⨀", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 239, Reference: "MO.OP"},
	{Operator: "⨁", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 240, Reference: "MO.OP"},
	{Operator: "⨂", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 241, Reference: "MO.OP"},
	{Operator: "⨃", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 242, Reference: "MO.OP"},
	{Operator: "⨄", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 243, Reference: "MO.OP"},
	{Operator: "⨅", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 244, Reference: "MO.OP"},
	{Operator: "⨆", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 245, Reference: "MO.OP"},
	{Operator: "⨇", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 246, Reference: "MO.OP"},
	{Operator: "⨈", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 247, Reference: "MO.OP"},
	{Operator: "⨉", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 248, Reference: "MO.OP"},
	{Operator: "⨊", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 249, Reference: "MO.OP"},
	{Operator: "⨋", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 250, Reference: "MO.INTEGRAL2"},
	{Operator: "⨌", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 1, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 251, Reference: "MO.INTEGRAL"},
	{Operator: "⨍", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 252, Reference: "MO.INTEGRAL2"},
	{Operator: "⨎", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 253, Reference: "MO.INTEGRAL2"},
	{Operator: "⨏", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 254, Reference: "MO.INTEGRAL2"},
	{Operator: "⨐", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 255, Reference: "MO.OP"},
	{Operator: "⨑", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 256, Reference: "MO.OP"},
	{Operator: "⨒", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 257, Reference: "MO.OP"},
	{Operator: "⨓", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 258, Reference: "MO.OP"},
	{Operator: "⨔", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 259, Reference: "MO.OP"},
	{Operator: "⨕", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 260, Reference: "MO.INTEGRAL2"},
	{Operator: "⨖", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 261, Reference: "MO.INTEGRAL2"},
	{Operator: "⨗", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 262, Reference: "MO.INTEGRAL2"},
	{Operator: "⨘", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 263, Reference: "MO.INTEGRAL2"},
	{Operator: "⨙", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 264, Reference: "MO.INTEGRAL2"},
	{Operator: "⨚", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 265, Reference: "MO.INTEGRAL2"},
	{Operator: "⨛", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 266, Reference: "MO.INTEGRAL2"},
	{Operator: "⨜", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 267, Reference: "MO.INTEGRAL2"},
	{Operator: "⫼", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 268, Reference: "MO.OP"},
	{Operator: "⫿", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 1, Properties: mjOperatorProperties{{Name: "largeop", Value: true}, {Name: "movablelimits", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 269, Reference: "MO.OP"},
}

var mjOperatorDictionaryPostfix = []mjOperatorDictionaryEntry{
	{Operator: "!!", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 0, TexClass: 2}, SourceLine: 272, Reference: "OPDEF"},
	{Operator: "!", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 0, TexClass: 5}, SourceLine: 273, Reference: ""},
	{Operator: "\"", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 274, Reference: "MO.ACCENT"},
	{Operator: "&", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 275, Reference: "MO.ORD"},
	{Operator: ")", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 276, Reference: "MO.CLOSE"},
	{Operator: "++", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 2}, SourceLine: 277, Reference: "OPDEF"},
	{Operator: "--", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 2}, SourceLine: 278, Reference: "OPDEF"},
	{Operator: "..", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 2}, SourceLine: 279, Reference: "OPDEF"},
	{Operator: "...", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 280, Reference: "MO.ORD"},
	{Operator: "'", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 281, Reference: "MO.ACCENT"},
	{Operator: "]", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 282, Reference: "MO.CLOSE"},
	{Operator: "^", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 283, Reference: "MO.WIDEACCENT"},
	{Operator: "_", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 284, Reference: "MO.WIDEACCENT"},
	{Operator: "`", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 285, Reference: "MO.ACCENT"},
	{Operator: "|", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 286, Reference: "MO.CLOSE"},
	{Operator: "}", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 287, Reference: "MO.CLOSE"},
	{Operator: "~", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 288, Reference: "MO.WIDEACCENT"},
	{Operator: "||", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 2, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 289, Reference: ""},
	{Operator: "|||", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 290, Reference: ""},
	{Operator: "¨", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 291, Reference: "MO.ACCENT"},
	{Operator: "ª", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 292, Reference: "MO.ACCENT"},
	{Operator: "¯", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 293, Reference: "MO.WIDEACCENT"},
	{Operator: "°", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 294, Reference: "MO.ORD"},
	{Operator: "²", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 295, Reference: "MO.ACCENT"},
	{Operator: "³", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 296, Reference: "MO.ACCENT"},
	{Operator: "´", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 297, Reference: "MO.ACCENT"},
	{Operator: "¸", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 298, Reference: "MO.ACCENT"},
	{Operator: "¹", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 299, Reference: "MO.ACCENT"},
	{Operator: "º", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 300, Reference: "MO.ACCENT"},
	{Operator: "ˆ", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 301, Reference: "MO.WIDEACCENT"},
	{Operator: "ˇ", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 302, Reference: "MO.WIDEACCENT"},
	{Operator: "ˉ", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 303, Reference: "MO.WIDEACCENT"},
	{Operator: "ˊ", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 304, Reference: "MO.ACCENT"},
	{Operator: "ˋ", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 305, Reference: "MO.ACCENT"},
	{Operator: "ˍ", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 306, Reference: "MO.WIDEACCENT"},
	{Operator: "˘", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 307, Reference: "MO.ACCENT"},
	{Operator: "˙", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 308, Reference: "MO.ACCENT"},
	{Operator: "˚", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 309, Reference: "MO.ACCENT"},
	{Operator: "˜", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 310, Reference: "MO.WIDEACCENT"},
	{Operator: "˝", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 311, Reference: "MO.ACCENT"},
	{Operator: "˷", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 312, Reference: "MO.WIDEACCENT"},
	{Operator: "̂", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 313, Reference: "MO.WIDEACCENT"},
	{Operator: "̑", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 314, Reference: "MO.ACCENT"},
	{Operator: "϶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 315, Reference: "MO.REL"},
	{Operator: "‖", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 316, Reference: ""},
	{Operator: "’", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}}}, SourceLine: 317, Reference: ""},
	{Operator: "‚", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 318, Reference: "MO.ACCENT"},
	{Operator: "‛", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 319, Reference: "MO.ACCENT"},
	{Operator: "”", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}}}, SourceLine: 320, Reference: ""},
	{Operator: "„", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 321, Reference: "MO.ACCENT"},
	{Operator: "‟", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 322, Reference: "MO.ACCENT"},
	{Operator: "′", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 323, Reference: "MO.ORD"},
	{Operator: "″", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 324, Reference: "MO.ACCENT"},
	{Operator: "‴", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 325, Reference: "MO.ACCENT"},
	{Operator: "‵", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 326, Reference: "MO.ACCENT"},
	{Operator: "‶", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 327, Reference: "MO.ACCENT"},
	{Operator: "‷", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 328, Reference: "MO.ACCENT"},
	{Operator: "‾", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 329, Reference: "MO.WIDEACCENT"},
	{Operator: "⁗", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 330, Reference: "MO.ACCENT"},
	{Operator: "⃛", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 331, Reference: "MO.ACCENT"},
	{Operator: "⃜", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 332, Reference: "MO.ACCENT"},
	{Operator: "⌉", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 333, Reference: "MO.CLOSE"},
	{Operator: "⌋", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 334, Reference: "MO.CLOSE"},
	{Operator: "〉", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 335, Reference: "MO.CLOSE"},
	{Operator: "⎴", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 336, Reference: "MO.WIDEACCENT"},
	{Operator: "⎵", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 337, Reference: "MO.WIDEACCENT"},
	{Operator: "⏜", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 338, Reference: "MO.WIDEACCENT"},
	{Operator: "⏝", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 339, Reference: "MO.WIDEACCENT"},
	{Operator: "⏞", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 340, Reference: "MO.WIDEACCENT"},
	{Operator: "⏟", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 341, Reference: "MO.WIDEACCENT"},
	{Operator: "⏠", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 342, Reference: "MO.WIDEACCENT"},
	{Operator: "⏡", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 343, Reference: "MO.WIDEACCENT"},
	{Operator: "■", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 344, Reference: "MO.BIN3"},
	{Operator: "□", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 345, Reference: "MO.BIN3"},
	{Operator: "▪", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 346, Reference: "MO.BIN3"},
	{Operator: "▫", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 347, Reference: "MO.BIN3"},
	{Operator: "▭", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 348, Reference: "MO.BIN3"},
	{Operator: "▮", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 349, Reference: "MO.BIN3"},
	{Operator: "▯", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 350, Reference: "MO.BIN3"},
	{Operator: "▰", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 351, Reference: "MO.BIN3"},
	{Operator: "▱", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 352, Reference: "MO.BIN3"},
	{Operator: "▲", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 353, Reference: "MO.BIN4"},
	{Operator: "▴", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 354, Reference: "MO.BIN4"},
	{Operator: "▶", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 355, Reference: "MO.BIN4"},
	{Operator: "▷", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 356, Reference: "MO.BIN4"},
	{Operator: "▸", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 357, Reference: "MO.BIN4"},
	{Operator: "▼", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 358, Reference: "MO.BIN4"},
	{Operator: "▾", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 359, Reference: "MO.BIN4"},
	{Operator: "◀", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 360, Reference: "MO.BIN4"},
	{Operator: "◁", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 361, Reference: "MO.BIN4"},
	{Operator: "◂", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 362, Reference: "MO.BIN4"},
	{Operator: "◄", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 363, Reference: "MO.BIN4"},
	{Operator: "◅", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 364, Reference: "MO.BIN4"},
	{Operator: "◆", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 365, Reference: "MO.BIN4"},
	{Operator: "◇", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 366, Reference: "MO.BIN4"},
	{Operator: "◈", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 367, Reference: "MO.BIN4"},
	{Operator: "◉", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 368, Reference: "MO.BIN4"},
	{Operator: "◌", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 369, Reference: "MO.BIN4"},
	{Operator: "◍", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 370, Reference: "MO.BIN4"},
	{Operator: "◎", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 371, Reference: "MO.BIN4"},
	{Operator: "●", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 372, Reference: "MO.BIN4"},
	{Operator: "◖", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 373, Reference: "MO.BIN4"},
	{Operator: "◗", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 374, Reference: "MO.BIN4"},
	{Operator: "◦", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 375, Reference: "MO.BIN4"},
	{Operator: "♭", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 2, TexClass: 0}, SourceLine: 376, Reference: "MO.ORD02"},
	{Operator: "♮", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 2, TexClass: 0}, SourceLine: 377, Reference: "MO.ORD02"},
	{Operator: "♯", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 2, TexClass: 0}, SourceLine: 378, Reference: "MO.ORD02"},
	{Operator: "❳", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 379, Reference: "MO.CLOSE"},
	{Operator: "⟧", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 380, Reference: "MO.CLOSE"},
	{Operator: "⟩", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 381, Reference: "MO.CLOSE"},
	{Operator: "⟫", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 382, Reference: "MO.CLOSE"},
	{Operator: "⟭", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 383, Reference: "MO.CLOSE"},
	{Operator: "⟯", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 384, Reference: "MO.CLOSE"},
	{Operator: "⦀", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 385, Reference: ""},
	{Operator: "⦄", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 386, Reference: "MO.CLOSE"},
	{Operator: "⦆", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 387, Reference: "MO.CLOSE"},
	{Operator: "⦈", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 388, Reference: "MO.CLOSE"},
	{Operator: "⦊", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 389, Reference: "MO.CLOSE"},
	{Operator: "⦌", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 390, Reference: "MO.CLOSE"},
	{Operator: "⦎", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 391, Reference: "MO.CLOSE"},
	{Operator: "⦐", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 392, Reference: "MO.CLOSE"},
	{Operator: "⦒", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 393, Reference: "MO.CLOSE"},
	{Operator: "⦔", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 394, Reference: "MO.CLOSE"},
	{Operator: "⦖", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 395, Reference: "MO.CLOSE"},
	{Operator: "⦘", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 396, Reference: "MO.CLOSE"},
	{Operator: "⧽", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 397, Reference: "MO.CLOSE"},
}

var mjOperatorDictionaryInfix = []mjOperatorDictionaryEntry{
	{Operator: "!=", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 400, Reference: "MO.BIN4"},
	{Operator: "#", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 401, Reference: "MO.ORD"},
	{Operator: "$", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 402, Reference: "MO.ORD"},
	{Operator: "%", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 0}, SourceLine: 403, Reference: ""},
	{Operator: "&&", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 404, Reference: "MO.BIN4"},
	{Operator: "", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 405, Reference: "MO.ORD"},
	{Operator: "*", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 406, Reference: "MO.BIN3"},
	{Operator: "**", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 2}, SourceLine: 407, Reference: "OPDEF"},
	{Operator: "*=", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 408, Reference: "MO.BIN4"},
	{Operator: "+", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 409, Reference: "MO.BIN4"},
	{Operator: "+=", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 410, Reference: "MO.BIN4"},
	{Operator: ",", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 3, TexClass: 6, Properties: mjOperatorProperties{{Name: "linebreakstyle", Value: "after"}, {Name: "separator", Value: true}}}, SourceLine: 411, Reference: ""},
	{Operator: "-", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 412, Reference: "MO.BIN4"},
	{Operator: "-=", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 413, Reference: "MO.BIN4"},
	{Operator: "->", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 2}, SourceLine: 414, Reference: "MO.BIN5"},
	{Operator: ".", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 3, TexClass: 6, Properties: mjOperatorProperties{{Name: "separator", Value: true}}}, SourceLine: 415, Reference: ""},
	{Operator: "/", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 0}, SourceLine: 416, Reference: "MO.ORD11"},
	{Operator: "//", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 2}, SourceLine: 417, Reference: "OPDEF"},
	{Operator: "/=", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 418, Reference: "MO.BIN4"},
	{Operator: ":", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 3}, SourceLine: 419, Reference: ""},
	{Operator: ":=", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 420, Reference: "MO.BIN4"},
	{Operator: ";", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 3, TexClass: 6, Properties: mjOperatorProperties{{Name: "linebreakstyle", Value: "after"}, {Name: "separator", Value: true}}}, SourceLine: 421, Reference: ""},
	{Operator: "<", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 422, Reference: "MO.REL"},
	{Operator: "<=", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 2}, SourceLine: 423, Reference: "MO.BIN5"},
	{Operator: "<>", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 2}, SourceLine: 424, Reference: "OPDEF"},
	{Operator: "=", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 425, Reference: "MO.REL"},
	{Operator: "==", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 426, Reference: "MO.BIN4"},
	{Operator: ">", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 427, Reference: "MO.REL"},
	{Operator: ">=", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 2}, SourceLine: 428, Reference: "MO.BIN5"},
	{Operator: "?", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 5}, SourceLine: 429, Reference: ""},
	{Operator: "@", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 0}, SourceLine: 430, Reference: "MO.ORD11"},
	{Operator: "\\", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 431, Reference: "MO.ORD"},
	{Operator: "^", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 1333, Reference: "MO.WIDEREL"},
	{Operator: "_", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 1334, Reference: "MO.WIDEREL"},
	{Operator: "|", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 2, TexClass: 0, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 434, Reference: ""},
	{Operator: "||", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 2, TexClass: 2, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 435, Reference: ""},
	{Operator: "|||", Definition: mjOperatorDefinition{Lspace: 2, Rspace: 2, TexClass: 0, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 436, Reference: ""},
	{Operator: "±", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 437, Reference: "MO.BIN4"},
	{Operator: "·", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 438, Reference: "MO.BIN4"},
	{Operator: "×", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 439, Reference: "MO.BIN4"},
	{Operator: "÷", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 440, Reference: "MO.BIN4"},
	{Operator: "ʹ", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 441, Reference: "MO.ORD"},
	{Operator: "̀", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 442, Reference: "MO.ACCENT"},
	{Operator: "́", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 443, Reference: "MO.ACCENT"},
	{Operator: "̃", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 444, Reference: "MO.WIDEACCENT"},
	{Operator: "̄", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 445, Reference: "MO.ACCENT"},
	{Operator: "̆", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 446, Reference: "MO.ACCENT"},
	{Operator: "̇", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 447, Reference: "MO.ACCENT"},
	{Operator: "̈", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 448, Reference: "MO.ACCENT"},
	{Operator: "̌", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 449, Reference: "MO.ACCENT"},
	{Operator: "̲", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 450, Reference: "MO.WIDEACCENT"},
	{Operator: "̸", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 3}, SourceLine: 451, Reference: "MO.REL4"},
	{Operator: "―", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 452, Reference: ""},
	{Operator: "‗", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 453, Reference: ""},
	{Operator: "†", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 454, Reference: "MO.BIN3"},
	{Operator: "‡", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 455, Reference: "MO.BIN3"},
	{Operator: "•", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 456, Reference: "MO.BIN4"},
	{Operator: "…", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 7}, SourceLine: 457, Reference: "MO.INNER"},
	{Operator: "⁃", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 458, Reference: "MO.BIN4"},
	{Operator: "⁄", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 459, Reference: "MO.TALLBIN"},
	{Operator: "⁡", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: -1}, SourceLine: 460, Reference: "MO.NONE"},
	{Operator: "⁢", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: -1}, SourceLine: 461, Reference: "MO.NONE"},
	{Operator: "⁣", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: -1, Properties: mjOperatorProperties{{Name: "linebreakstyle", Value: "after"}, {Name: "separator", Value: true}}}, SourceLine: 462, Reference: ""},
	{Operator: "⁤", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: -1}, SourceLine: 463, Reference: "MO.NONE"},
	{Operator: "⃗", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 464, Reference: "MO.ACCENT"},
	{Operator: "ℑ", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 465, Reference: "MO.ORD"},
	{Operator: "ℓ", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 466, Reference: "MO.ORD"},
	{Operator: "℘", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 467, Reference: "MO.ORD"},
	{Operator: "ℜ", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 468, Reference: "MO.ORD"},
	{Operator: "←", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 469, Reference: "MO.WIDEREL"},
	{Operator: "↑", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 470, Reference: "MO.RELSTRETCH"},
	{Operator: "→", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 471, Reference: "MO.WIDEREL"},
	{Operator: "↓", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 472, Reference: "MO.RELSTRETCH"},
	{Operator: "↔", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 473, Reference: "MO.WIDEREL"},
	{Operator: "↕", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 474, Reference: "MO.RELSTRETCH"},
	{Operator: "↖", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 475, Reference: "MO.RELSTRETCH"},
	{Operator: "↗", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 476, Reference: "MO.RELSTRETCH"},
	{Operator: "↘", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 477, Reference: "MO.RELSTRETCH"},
	{Operator: "↙", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 478, Reference: "MO.RELSTRETCH"},
	{Operator: "↚", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 479, Reference: "MO.RELACCENT"},
	{Operator: "↛", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 480, Reference: "MO.RELACCENT"},
	{Operator: "↜", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 481, Reference: "MO.WIDEREL"},
	{Operator: "↝", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 482, Reference: "MO.WIDEREL"},
	{Operator: "↞", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 483, Reference: "MO.WIDEREL"},
	{Operator: "↟", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 484, Reference: "MO.WIDEREL"},
	{Operator: "↠", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 485, Reference: "MO.WIDEREL"},
	{Operator: "↡", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 486, Reference: "MO.RELSTRETCH"},
	{Operator: "↢", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 487, Reference: "MO.WIDEREL"},
	{Operator: "↣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 488, Reference: "MO.WIDEREL"},
	{Operator: "↤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 489, Reference: "MO.WIDEREL"},
	{Operator: "↥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 490, Reference: "MO.RELSTRETCH"},
	{Operator: "↦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 491, Reference: "MO.WIDEREL"},
	{Operator: "↧", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 492, Reference: "MO.RELSTRETCH"},
	{Operator: "↨", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 493, Reference: "MO.RELSTRETCH"},
	{Operator: "↩", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 494, Reference: "MO.WIDEREL"},
	{Operator: "↪", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 495, Reference: "MO.WIDEREL"},
	{Operator: "↫", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 496, Reference: "MO.WIDEREL"},
	{Operator: "↬", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 497, Reference: "MO.WIDEREL"},
	{Operator: "↭", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 498, Reference: "MO.WIDEREL"},
	{Operator: "↮", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 499, Reference: "MO.RELACCENT"},
	{Operator: "↯", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 500, Reference: "MO.RELSTRETCH"},
	{Operator: "↰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 501, Reference: "MO.RELSTRETCH"},
	{Operator: "↱", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 502, Reference: "MO.RELSTRETCH"},
	{Operator: "↲", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 503, Reference: "MO.RELSTRETCH"},
	{Operator: "↳", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 504, Reference: "MO.RELSTRETCH"},
	{Operator: "↴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 505, Reference: "MO.RELSTRETCH"},
	{Operator: "↵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 506, Reference: "MO.RELSTRETCH"},
	{Operator: "↶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 507, Reference: "MO.RELACCENT"},
	{Operator: "↷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 508, Reference: "MO.RELACCENT"},
	{Operator: "↸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 509, Reference: "MO.REL"},
	{Operator: "↹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 510, Reference: "MO.WIDEREL"},
	{Operator: "↺", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 511, Reference: "MO.REL"},
	{Operator: "↻", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 512, Reference: "MO.REL"},
	{Operator: "↼", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 513, Reference: "MO.WIDEREL"},
	{Operator: "↽", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 514, Reference: "MO.WIDEREL"},
	{Operator: "↾", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 515, Reference: "MO.RELSTRETCH"},
	{Operator: "↿", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 516, Reference: "MO.RELSTRETCH"},
	{Operator: "⇀", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 517, Reference: "MO.WIDEREL"},
	{Operator: "⇁", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 518, Reference: "MO.WIDEREL"},
	{Operator: "⇂", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 519, Reference: "MO.RELSTRETCH"},
	{Operator: "⇃", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 520, Reference: "MO.RELSTRETCH"},
	{Operator: "⇄", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 521, Reference: "MO.WIDEREL"},
	{Operator: "⇅", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 522, Reference: "MO.RELSTRETCH"},
	{Operator: "⇆", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 523, Reference: "MO.WIDEREL"},
	{Operator: "⇇", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 524, Reference: "MO.WIDEREL"},
	{Operator: "⇈", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 525, Reference: "MO.RELSTRETCH"},
	{Operator: "⇉", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 526, Reference: "MO.WIDEREL"},
	{Operator: "⇊", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 527, Reference: "MO.RELSTRETCH"},
	{Operator: "⇋", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 528, Reference: "MO.WIDEREL"},
	{Operator: "⇌", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 529, Reference: "MO.WIDEREL"},
	{Operator: "⇍", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 530, Reference: "MO.RELACCENT"},
	{Operator: "⇎", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 531, Reference: "MO.RELACCENT"},
	{Operator: "⇏", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 532, Reference: "MO.RELACCENT"},
	{Operator: "⇐", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 533, Reference: "MO.WIDEREL"},
	{Operator: "⇑", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 534, Reference: "MO.RELSTRETCH"},
	{Operator: "⇒", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 535, Reference: "MO.WIDEREL"},
	{Operator: "⇓", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 536, Reference: "MO.RELSTRETCH"},
	{Operator: "⇔", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 537, Reference: "MO.WIDEREL"},
	{Operator: "⇕", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 538, Reference: "MO.RELSTRETCH"},
	{Operator: "⇖", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 539, Reference: "MO.RELSTRETCH"},
	{Operator: "⇗", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 540, Reference: "MO.RELSTRETCH"},
	{Operator: "⇘", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 541, Reference: "MO.RELSTRETCH"},
	{Operator: "⇙", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 542, Reference: "MO.RELSTRETCH"},
	{Operator: "⇚", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 543, Reference: "MO.WIDEREL"},
	{Operator: "⇛", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 544, Reference: "MO.WIDEREL"},
	{Operator: "⇜", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 545, Reference: "MO.WIDEREL"},
	{Operator: "⇝", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 546, Reference: "MO.WIDEREL"},
	{Operator: "⇞", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 547, Reference: "MO.REL"},
	{Operator: "⇟", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 548, Reference: "MO.REL"},
	{Operator: "⇠", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 549, Reference: "MO.WIDEREL"},
	{Operator: "⇡", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 550, Reference: "MO.RELSTRETCH"},
	{Operator: "⇢", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 551, Reference: "MO.WIDEREL"},
	{Operator: "⇣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 552, Reference: "MO.RELSTRETCH"},
	{Operator: "⇤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 553, Reference: "MO.WIDEREL"},
	{Operator: "⇥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 554, Reference: "MO.WIDEREL"},
	{Operator: "⇦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 555, Reference: "MO.WIDEREL"},
	{Operator: "⇧", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 556, Reference: "MO.RELSTRETCH"},
	{Operator: "⇨", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 557, Reference: "MO.WIDEREL"},
	{Operator: "⇩", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 558, Reference: "MO.RELSTRETCH"},
	{Operator: "⇪", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 559, Reference: "MO.RELSTRETCH"},
	{Operator: "⇫", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 560, Reference: "MO.RELSTRETCH"},
	{Operator: "⇬", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 561, Reference: "MO.RELSTRETCH"},
	{Operator: "⇭", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 562, Reference: "MO.RELSTRETCH"},
	{Operator: "⇮", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 563, Reference: "MO.RELSTRETCH"},
	{Operator: "⇯", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 564, Reference: "MO.RELSTRETCH"},
	{Operator: "⇰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 565, Reference: "MO.WIDEREL"},
	{Operator: "⇱", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 566, Reference: "MO.REL"},
	{Operator: "⇲", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 567, Reference: "MO.REL"},
	{Operator: "⇳", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 568, Reference: "MO.RELSTRETCH"},
	{Operator: "⇴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 569, Reference: "MO.RELACCENT"},
	{Operator: "⇵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 570, Reference: "MO.RELSTRETCH"},
	{Operator: "⇶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 571, Reference: "MO.WIDEREL"},
	{Operator: "⇷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 572, Reference: "MO.RELACCENT"},
	{Operator: "⇸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 573, Reference: "MO.RELACCENT"},
	{Operator: "⇹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 574, Reference: "MO.RELACCENT"},
	{Operator: "⇺", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 575, Reference: "MO.RELACCENT"},
	{Operator: "⇻", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 576, Reference: "MO.RELACCENT"},
	{Operator: "⇼", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 577, Reference: "MO.RELACCENT"},
	{Operator: "⇽", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 578, Reference: "MO.WIDEREL"},
	{Operator: "⇾", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 579, Reference: "MO.WIDEREL"},
	{Operator: "⇿", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 580, Reference: "MO.WIDEREL"},
	{Operator: "∁", Definition: mjOperatorDefinition{Lspace: 1, Rspace: 2, TexClass: 0}, SourceLine: 581, Reference: "OPDEF"},
	{Operator: "∅", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 582, Reference: "MO.ORD"},
	{Operator: "∆", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 583, Reference: "MO.BIN3"},
	{Operator: "∈", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 584, Reference: "MO.REL"},
	{Operator: "∉", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 585, Reference: "MO.REL"},
	{Operator: "∊", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 586, Reference: "MO.REL"},
	{Operator: "∋", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 587, Reference: "MO.REL"},
	{Operator: "∌", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 588, Reference: "MO.REL"},
	{Operator: "∍", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 589, Reference: "MO.REL"},
	{Operator: "∎", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 590, Reference: "MO.BIN3"},
	{Operator: "−", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 591, Reference: "MO.BIN4"},
	{Operator: "∓", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 592, Reference: "MO.BIN4"},
	{Operator: "∔", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 593, Reference: "MO.BIN4"},
	{Operator: "∕", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 594, Reference: "MO.TALLBIN"},
	{Operator: "∖", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 595, Reference: "MO.BIN4"},
	{Operator: "∗", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 596, Reference: "MO.BIN4"},
	{Operator: "∘", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 597, Reference: "MO.BIN4"},
	{Operator: "∙", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 598, Reference: "MO.BIN4"},
	{Operator: "∝", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 599, Reference: "MO.REL"},
	{Operator: "∞", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 600, Reference: "MO.ORD"},
	{Operator: "∟", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 601, Reference: "MO.REL"},
	{Operator: "∣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 602, Reference: "MO.REL"},
	{Operator: "∤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 603, Reference: "MO.REL"},
	{Operator: "∥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 604, Reference: "MO.REL"},
	{Operator: "∦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 605, Reference: "MO.REL"},
	{Operator: "∧", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 606, Reference: "MO.BIN4"},
	{Operator: "∨", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 607, Reference: "MO.BIN4"},
	{Operator: "∩", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 608, Reference: "MO.BIN4"},
	{Operator: "∪", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 609, Reference: "MO.BIN4"},
	{Operator: "∴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 610, Reference: "MO.REL"},
	{Operator: "∵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 611, Reference: "MO.REL"},
	{Operator: "∶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 612, Reference: "MO.REL"},
	{Operator: "∷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 613, Reference: "MO.REL"},
	{Operator: "∸", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 614, Reference: "MO.BIN4"},
	{Operator: "∹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 615, Reference: "MO.REL"},
	{Operator: "∺", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 616, Reference: "MO.BIN4"},
	{Operator: "∻", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 617, Reference: "MO.REL"},
	{Operator: "∼", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 618, Reference: "MO.REL"},
	{Operator: "∽", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 619, Reference: "MO.REL"},
	{Operator: "∽̱", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 620, Reference: "MO.BIN3"},
	{Operator: "∾", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 621, Reference: "MO.REL"},
	{Operator: "∿", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 622, Reference: "MO.BIN3"},
	{Operator: "≀", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 623, Reference: "MO.BIN4"},
	{Operator: "≁", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 624, Reference: "MO.REL"},
	{Operator: "≂", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 625, Reference: "MO.REL"},
	{Operator: "≂̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 626, Reference: "MO.REL"},
	{Operator: "≃", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 627, Reference: "MO.REL"},
	{Operator: "≄", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 628, Reference: "MO.REL"},
	{Operator: "≅", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 629, Reference: "MO.REL"},
	{Operator: "≆", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 630, Reference: "MO.REL"},
	{Operator: "≇", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 631, Reference: "MO.REL"},
	{Operator: "≈", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 632, Reference: "MO.REL"},
	{Operator: "≉", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 633, Reference: "MO.REL"},
	{Operator: "≊", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 634, Reference: "MO.REL"},
	{Operator: "≋", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 635, Reference: "MO.REL"},
	{Operator: "≌", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 636, Reference: "MO.REL"},
	{Operator: "≍", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 637, Reference: "MO.REL"},
	{Operator: "≎", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 638, Reference: "MO.REL"},
	{Operator: "≎̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 639, Reference: "MO.REL"},
	{Operator: "≏", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 640, Reference: "MO.REL"},
	{Operator: "≏̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 641, Reference: "MO.REL"},
	{Operator: "≐", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 642, Reference: "MO.REL"},
	{Operator: "≑", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 643, Reference: "MO.REL"},
	{Operator: "≒", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 644, Reference: "MO.REL"},
	{Operator: "≓", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 645, Reference: "MO.REL"},
	{Operator: "≔", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 646, Reference: "MO.REL"},
	{Operator: "≕", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 647, Reference: "MO.REL"},
	{Operator: "≖", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 648, Reference: "MO.REL"},
	{Operator: "≗", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 649, Reference: "MO.REL"},
	{Operator: "≘", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 650, Reference: "MO.REL"},
	{Operator: "≙", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 651, Reference: "MO.REL"},
	{Operator: "≚", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 652, Reference: "MO.REL"},
	{Operator: "≛", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 653, Reference: "MO.REL"},
	{Operator: "≜", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 654, Reference: "MO.REL"},
	{Operator: "≝", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 655, Reference: "MO.REL"},
	{Operator: "≞", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 656, Reference: "MO.REL"},
	{Operator: "≟", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 657, Reference: "MO.REL"},
	{Operator: "≠", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 658, Reference: "MO.REL"},
	{Operator: "≡", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 659, Reference: "MO.REL"},
	{Operator: "≢", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 660, Reference: "MO.REL"},
	{Operator: "≣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 661, Reference: "MO.REL"},
	{Operator: "≤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 662, Reference: "MO.REL"},
	{Operator: "≥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 663, Reference: "MO.REL"},
	{Operator: "≦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 664, Reference: "MO.REL"},
	{Operator: "≦̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 665, Reference: "MO.REL"},
	{Operator: "≧", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 666, Reference: "MO.REL"},
	{Operator: "≨", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 667, Reference: "MO.REL"},
	{Operator: "≩", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 668, Reference: "MO.REL"},
	{Operator: "≪", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 669, Reference: "MO.REL"},
	{Operator: "≪̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 670, Reference: "MO.REL"},
	{Operator: "≫", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 671, Reference: "MO.REL"},
	{Operator: "≫̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 672, Reference: "MO.REL"},
	{Operator: "≬", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 673, Reference: "MO.REL"},
	{Operator: "≭", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 674, Reference: "MO.REL"},
	{Operator: "≮", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 675, Reference: "MO.REL"},
	{Operator: "≯", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 676, Reference: "MO.REL"},
	{Operator: "≰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 677, Reference: "MO.REL"},
	{Operator: "≱", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 678, Reference: "MO.REL"},
	{Operator: "≲", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 679, Reference: "MO.REL"},
	{Operator: "≳", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 680, Reference: "MO.REL"},
	{Operator: "≴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 681, Reference: "MO.REL"},
	{Operator: "≵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 682, Reference: "MO.REL"},
	{Operator: "≶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 683, Reference: "MO.REL"},
	{Operator: "≷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 684, Reference: "MO.REL"},
	{Operator: "≸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 685, Reference: "MO.REL"},
	{Operator: "≹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 686, Reference: "MO.REL"},
	{Operator: "≺", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 687, Reference: "MO.REL"},
	{Operator: "≻", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 688, Reference: "MO.REL"},
	{Operator: "≼", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 689, Reference: "MO.REL"},
	{Operator: "≽", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 690, Reference: "MO.REL"},
	{Operator: "≾", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 691, Reference: "MO.REL"},
	{Operator: "≿", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 692, Reference: "MO.REL"},
	{Operator: "≿̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 693, Reference: "MO.REL"},
	{Operator: "⊀", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 694, Reference: "MO.REL"},
	{Operator: "⊁", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 695, Reference: "MO.REL"},
	{Operator: "⊂", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 696, Reference: "MO.REL"},
	{Operator: "⊂⃒", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 697, Reference: "MO.REL"},
	{Operator: "⊃", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 698, Reference: "MO.REL"},
	{Operator: "⊃⃒", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 699, Reference: "MO.REL"},
	{Operator: "⊄", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 700, Reference: "MO.REL"},
	{Operator: "⊅", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 701, Reference: "MO.REL"},
	{Operator: "⊆", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 702, Reference: "MO.REL"},
	{Operator: "⊇", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 703, Reference: "MO.REL"},
	{Operator: "⊈", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 704, Reference: "MO.REL"},
	{Operator: "⊉", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 705, Reference: "MO.REL"},
	{Operator: "⊊", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 706, Reference: "MO.REL"},
	{Operator: "⊋", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 707, Reference: "MO.REL"},
	{Operator: "⊌", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 708, Reference: "MO.BIN4"},
	{Operator: "⊍", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 709, Reference: "MO.BIN4"},
	{Operator: "⊎", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 710, Reference: "MO.BIN4"},
	{Operator: "⊏", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 711, Reference: "MO.REL"},
	{Operator: "⊏̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 712, Reference: "MO.REL"},
	{Operator: "⊐", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 713, Reference: "MO.REL"},
	{Operator: "⊐̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 714, Reference: "MO.REL"},
	{Operator: "⊑", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 715, Reference: "MO.REL"},
	{Operator: "⊒", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 716, Reference: "MO.REL"},
	{Operator: "⊓", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 717, Reference: "MO.BIN4"},
	{Operator: "⊔", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 718, Reference: "MO.BIN4"},
	{Operator: "⊕", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 719, Reference: "MO.BIN4"},
	{Operator: "⊖", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 720, Reference: "MO.BIN4"},
	{Operator: "⊗", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 721, Reference: "MO.BIN4"},
	{Operator: "⊘", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 722, Reference: "MO.BIN4"},
	{Operator: "⊙", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 723, Reference: "MO.BIN4"},
	{Operator: "⊚", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 724, Reference: "MO.BIN4"},
	{Operator: "⊛", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 725, Reference: "MO.BIN4"},
	{Operator: "⊜", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 726, Reference: "MO.BIN4"},
	{Operator: "⊝", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 727, Reference: "MO.BIN4"},
	{Operator: "⊞", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 728, Reference: "MO.BIN4"},
	{Operator: "⊟", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 729, Reference: "MO.BIN4"},
	{Operator: "⊠", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 730, Reference: "MO.BIN4"},
	{Operator: "⊡", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 731, Reference: "MO.BIN4"},
	{Operator: "⊢", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 732, Reference: "MO.REL"},
	{Operator: "⊣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 733, Reference: "MO.REL"},
	{Operator: "⊤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 0}, SourceLine: 734, Reference: "MO.ORD55"},
	{Operator: "⊥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 735, Reference: "MO.REL"},
	{Operator: "⊦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 736, Reference: "MO.REL"},
	{Operator: "⊧", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 737, Reference: "MO.REL"},
	{Operator: "⊨", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 738, Reference: "MO.REL"},
	{Operator: "⊩", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 739, Reference: "MO.REL"},
	{Operator: "⊪", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 740, Reference: "MO.REL"},
	{Operator: "⊫", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 741, Reference: "MO.REL"},
	{Operator: "⊬", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 742, Reference: "MO.REL"},
	{Operator: "⊭", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 743, Reference: "MO.REL"},
	{Operator: "⊮", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 744, Reference: "MO.REL"},
	{Operator: "⊯", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 745, Reference: "MO.REL"},
	{Operator: "⊰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 746, Reference: "MO.REL"},
	{Operator: "⊱", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 747, Reference: "MO.REL"},
	{Operator: "⊲", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 748, Reference: "MO.REL"},
	{Operator: "⊳", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 749, Reference: "MO.REL"},
	{Operator: "⊴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 750, Reference: "MO.REL"},
	{Operator: "⊵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 751, Reference: "MO.REL"},
	{Operator: "⊶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 752, Reference: "MO.REL"},
	{Operator: "⊷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 753, Reference: "MO.REL"},
	{Operator: "⊸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 754, Reference: "MO.REL"},
	{Operator: "⊹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 755, Reference: "MO.REL"},
	{Operator: "⊺", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 756, Reference: "MO.BIN4"},
	{Operator: "⊻", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 757, Reference: "MO.BIN4"},
	{Operator: "⊼", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 758, Reference: "MO.BIN4"},
	{Operator: "⊽", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 759, Reference: "MO.BIN4"},
	{Operator: "⊾", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 760, Reference: "MO.BIN3"},
	{Operator: "⊿", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 761, Reference: "MO.BIN3"},
	{Operator: "⋄", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 762, Reference: "MO.BIN4"},
	{Operator: "⋅", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 763, Reference: "MO.BIN4"},
	{Operator: "⋆", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 764, Reference: "MO.BIN4"},
	{Operator: "⋇", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 765, Reference: "MO.BIN4"},
	{Operator: "⋈", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 766, Reference: "MO.REL"},
	{Operator: "⋉", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 767, Reference: "MO.BIN4"},
	{Operator: "⋊", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 768, Reference: "MO.BIN4"},
	{Operator: "⋋", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 769, Reference: "MO.BIN4"},
	{Operator: "⋌", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 770, Reference: "MO.BIN4"},
	{Operator: "⋍", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 771, Reference: "MO.REL"},
	{Operator: "⋎", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 772, Reference: "MO.BIN4"},
	{Operator: "⋏", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 773, Reference: "MO.BIN4"},
	{Operator: "⋐", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 774, Reference: "MO.REL"},
	{Operator: "⋑", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 775, Reference: "MO.REL"},
	{Operator: "⋒", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 776, Reference: "MO.BIN4"},
	{Operator: "⋓", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 777, Reference: "MO.BIN4"},
	{Operator: "⋔", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 778, Reference: "MO.REL"},
	{Operator: "⋕", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 779, Reference: "MO.REL"},
	{Operator: "⋖", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 780, Reference: "MO.REL"},
	{Operator: "⋗", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 781, Reference: "MO.REL"},
	{Operator: "⋘", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 782, Reference: "MO.REL"},
	{Operator: "⋙", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 783, Reference: "MO.REL"},
	{Operator: "⋚", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 784, Reference: "MO.REL"},
	{Operator: "⋛", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 785, Reference: "MO.REL"},
	{Operator: "⋜", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 786, Reference: "MO.REL"},
	{Operator: "⋝", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 787, Reference: "MO.REL"},
	{Operator: "⋞", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 788, Reference: "MO.REL"},
	{Operator: "⋟", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 789, Reference: "MO.REL"},
	{Operator: "⋠", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 790, Reference: "MO.REL"},
	{Operator: "⋡", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 791, Reference: "MO.REL"},
	{Operator: "⋢", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 792, Reference: "MO.REL"},
	{Operator: "⋣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 793, Reference: "MO.REL"},
	{Operator: "⋤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 794, Reference: "MO.REL"},
	{Operator: "⋥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 795, Reference: "MO.REL"},
	{Operator: "⋦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 796, Reference: "MO.REL"},
	{Operator: "⋧", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 797, Reference: "MO.REL"},
	{Operator: "⋨", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 798, Reference: "MO.REL"},
	{Operator: "⋩", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 799, Reference: "MO.REL"},
	{Operator: "⋪", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 800, Reference: "MO.REL"},
	{Operator: "⋫", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 801, Reference: "MO.REL"},
	{Operator: "⋬", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 802, Reference: "MO.REL"},
	{Operator: "⋭", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 803, Reference: "MO.REL"},
	{Operator: "⋮", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 0}, SourceLine: 804, Reference: "MO.ORD55"},
	{Operator: "⋯", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 7}, SourceLine: 805, Reference: "MO.INNER"},
	{Operator: "⋰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 806, Reference: "MO.REL"},
	{Operator: "⋱", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 7}, SourceLine: 807, Reference: ""},
	{Operator: "⋲", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 808, Reference: "MO.REL"},
	{Operator: "⋳", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 809, Reference: "MO.REL"},
	{Operator: "⋴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 810, Reference: "MO.REL"},
	{Operator: "⋵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 811, Reference: "MO.REL"},
	{Operator: "⋶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 812, Reference: "MO.REL"},
	{Operator: "⋷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 813, Reference: "MO.REL"},
	{Operator: "⋸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 814, Reference: "MO.REL"},
	{Operator: "⋹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 815, Reference: "MO.REL"},
	{Operator: "⋺", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 816, Reference: "MO.REL"},
	{Operator: "⋻", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 817, Reference: "MO.REL"},
	{Operator: "⋼", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 818, Reference: "MO.REL"},
	{Operator: "⋽", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 819, Reference: "MO.REL"},
	{Operator: "⋾", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 820, Reference: "MO.REL"},
	{Operator: "⋿", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 821, Reference: "MO.REL"},
	{Operator: "⌅", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 822, Reference: "MO.BIN3"},
	{Operator: "⌆", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 823, Reference: "MO.BIN3"},
	{Operator: "⌢", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 3}, SourceLine: 824, Reference: "MO.REL4"},
	{Operator: "⌣", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 3}, SourceLine: 825, Reference: "MO.REL4"},
	{Operator: "〈", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 826, Reference: "MO.OPEN"},
	{Operator: "〉", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 827, Reference: "MO.CLOSE"},
	{Operator: "⎪", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 828, Reference: "MO.ORD"},
	{Operator: "⎯", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 829, Reference: ""},
	{Operator: "⎰", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 830, Reference: "MO.OPEN"},
	{Operator: "⎱", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 831, Reference: "MO.CLOSE"},
	{Operator: "─", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 832, Reference: "MO.ORD"},
	{Operator: "△", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 833, Reference: "MO.BIN4"},
	{Operator: "▵", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 834, Reference: "MO.BIN4"},
	{Operator: "▹", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 835, Reference: "MO.BIN4"},
	{Operator: "▽", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 836, Reference: "MO.BIN4"},
	{Operator: "▿", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 837, Reference: "MO.BIN4"},
	{Operator: "◃", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 838, Reference: "MO.BIN4"},
	{Operator: "◯", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 839, Reference: "MO.BIN3"},
	{Operator: "♠", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 840, Reference: "MO.ORD"},
	{Operator: "♡", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 841, Reference: "MO.ORD"},
	{Operator: "♢", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 842, Reference: "MO.ORD"},
	{Operator: "♣", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0}, SourceLine: 843, Reference: "MO.ORD"},
	{Operator: "❘", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 844, Reference: "MO.REL"},
	{Operator: "⟰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 845, Reference: "MO.RELSTRETCH"},
	{Operator: "⟱", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 846, Reference: "MO.RELSTRETCH"},
	{Operator: "⟵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 847, Reference: "MO.WIDEREL"},
	{Operator: "⟶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 848, Reference: "MO.WIDEREL"},
	{Operator: "⟷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 849, Reference: "MO.WIDEREL"},
	{Operator: "⟸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 850, Reference: "MO.WIDEREL"},
	{Operator: "⟹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 851, Reference: "MO.WIDEREL"},
	{Operator: "⟺", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 852, Reference: "MO.WIDEREL"},
	{Operator: "⟻", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 853, Reference: "MO.WIDEREL"},
	{Operator: "⟼", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 854, Reference: "MO.WIDEREL"},
	{Operator: "⟽", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 855, Reference: "MO.WIDEREL"},
	{Operator: "⟾", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 856, Reference: "MO.WIDEREL"},
	{Operator: "⟿", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 857, Reference: "MO.WIDEREL"},
	{Operator: "⤀", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 858, Reference: "MO.RELACCENT"},
	{Operator: "⤁", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 859, Reference: "MO.RELACCENT"},
	{Operator: "⤂", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 860, Reference: "MO.RELACCENT"},
	{Operator: "⤃", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 861, Reference: "MO.RELACCENT"},
	{Operator: "⤄", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 862, Reference: "MO.RELACCENT"},
	{Operator: "⤅", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 863, Reference: "MO.RELACCENT"},
	{Operator: "⤆", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 864, Reference: "MO.RELACCENT"},
	{Operator: "⤇", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 865, Reference: "MO.RELACCENT"},
	{Operator: "⤈", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 866, Reference: "MO.REL"},
	{Operator: "⤉", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 867, Reference: "MO.REL"},
	{Operator: "⤊", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 868, Reference: "MO.RELSTRETCH"},
	{Operator: "⤋", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 869, Reference: "MO.RELSTRETCH"},
	{Operator: "⤌", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 870, Reference: "MO.WIDEREL"},
	{Operator: "⤍", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 871, Reference: "MO.WIDEREL"},
	{Operator: "⤎", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 872, Reference: "MO.WIDEREL"},
	{Operator: "⤏", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 873, Reference: "MO.WIDEREL"},
	{Operator: "⤐", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 874, Reference: "MO.WIDEREL"},
	{Operator: "⤑", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 875, Reference: "MO.RELACCENT"},
	{Operator: "⤒", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 876, Reference: "MO.RELSTRETCH"},
	{Operator: "⤓", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 877, Reference: "MO.RELSTRETCH"},
	{Operator: "⤔", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 878, Reference: "MO.RELACCENT"},
	{Operator: "⤕", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 879, Reference: "MO.RELACCENT"},
	{Operator: "⤖", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 880, Reference: "MO.RELACCENT"},
	{Operator: "⤗", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 881, Reference: "MO.RELACCENT"},
	{Operator: "⤘", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 882, Reference: "MO.RELACCENT"},
	{Operator: "⤙", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 883, Reference: "MO.RELACCENT"},
	{Operator: "⤚", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 884, Reference: "MO.RELACCENT"},
	{Operator: "⤛", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 885, Reference: "MO.RELACCENT"},
	{Operator: "⤜", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 886, Reference: "MO.RELACCENT"},
	{Operator: "⤝", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 887, Reference: "MO.RELACCENT"},
	{Operator: "⤞", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 888, Reference: "MO.RELACCENT"},
	{Operator: "⤟", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 889, Reference: "MO.RELACCENT"},
	{Operator: "⤠", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 890, Reference: "MO.RELACCENT"},
	{Operator: "⤡", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 891, Reference: "MO.RELSTRETCH"},
	{Operator: "⤢", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 892, Reference: "MO.RELSTRETCH"},
	{Operator: "⤣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 893, Reference: "MO.REL"},
	{Operator: "⤤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 894, Reference: "MO.REL"},
	{Operator: "⤥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 895, Reference: "MO.REL"},
	{Operator: "⤦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 896, Reference: "MO.REL"},
	{Operator: "⤧", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 897, Reference: "MO.REL"},
	{Operator: "⤨", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 898, Reference: "MO.REL"},
	{Operator: "⤩", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 899, Reference: "MO.REL"},
	{Operator: "⤪", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 900, Reference: "MO.REL"},
	{Operator: "⤫", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 901, Reference: "MO.REL"},
	{Operator: "⤬", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 902, Reference: "MO.REL"},
	{Operator: "⤭", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 903, Reference: "MO.REL"},
	{Operator: "⤮", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 904, Reference: "MO.REL"},
	{Operator: "⤯", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 905, Reference: "MO.REL"},
	{Operator: "⤰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 906, Reference: "MO.REL"},
	{Operator: "⤱", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 907, Reference: "MO.REL"},
	{Operator: "⤲", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 908, Reference: "MO.REL"},
	{Operator: "⤳", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 909, Reference: "MO.RELACCENT"},
	{Operator: "⤴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 910, Reference: "MO.REL"},
	{Operator: "⤵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 911, Reference: "MO.REL"},
	{Operator: "⤶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 912, Reference: "MO.REL"},
	{Operator: "⤷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 913, Reference: "MO.REL"},
	{Operator: "⤸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 914, Reference: "MO.REL"},
	{Operator: "⤹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 915, Reference: "MO.REL"},
	{Operator: "⤺", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 916, Reference: "MO.RELACCENT"},
	{Operator: "⤻", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 917, Reference: "MO.RELACCENT"},
	{Operator: "⤼", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 918, Reference: "MO.RELACCENT"},
	{Operator: "⤽", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 919, Reference: "MO.RELACCENT"},
	{Operator: "⤾", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 920, Reference: "MO.REL"},
	{Operator: "⤿", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 921, Reference: "MO.REL"},
	{Operator: "⥀", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 922, Reference: "MO.REL"},
	{Operator: "⥁", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 923, Reference: "MO.REL"},
	{Operator: "⥂", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 924, Reference: "MO.RELACCENT"},
	{Operator: "⥃", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 925, Reference: "MO.RELACCENT"},
	{Operator: "⥄", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 926, Reference: "MO.RELACCENT"},
	{Operator: "⥅", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 927, Reference: "MO.RELACCENT"},
	{Operator: "⥆", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 928, Reference: "MO.RELACCENT"},
	{Operator: "⥇", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 929, Reference: "MO.RELACCENT"},
	{Operator: "⥈", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 930, Reference: "MO.RELACCENT"},
	{Operator: "⥉", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 931, Reference: "MO.REL"},
	{Operator: "⥊", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 932, Reference: "MO.RELACCENT"},
	{Operator: "⥋", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 933, Reference: "MO.RELACCENT"},
	{Operator: "⥌", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 934, Reference: "MO.REL"},
	{Operator: "⥍", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 935, Reference: "MO.REL"},
	{Operator: "⥎", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 936, Reference: "MO.WIDEREL"},
	{Operator: "⥏", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 937, Reference: "MO.RELSTRETCH"},
	{Operator: "⥐", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 938, Reference: "MO.WIDEREL"},
	{Operator: "⥑", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 939, Reference: "MO.RELSTRETCH"},
	{Operator: "⥒", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 940, Reference: "MO.WIDEREL"},
	{Operator: "⥓", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 941, Reference: "MO.WIDEREL"},
	{Operator: "⥔", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 942, Reference: "MO.RELSTRETCH"},
	{Operator: "⥕", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 943, Reference: "MO.RELSTRETCH"},
	{Operator: "⥖", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 944, Reference: "MO.RELSTRETCH"},
	{Operator: "⥗", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 945, Reference: "MO.RELSTRETCH"},
	{Operator: "⥘", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 946, Reference: "MO.RELSTRETCH"},
	{Operator: "⥙", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 947, Reference: "MO.RELSTRETCH"},
	{Operator: "⥚", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 948, Reference: "MO.WIDEREL"},
	{Operator: "⥛", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 949, Reference: "MO.WIDEREL"},
	{Operator: "⥜", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 950, Reference: "MO.RELSTRETCH"},
	{Operator: "⥝", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 951, Reference: "MO.RELSTRETCH"},
	{Operator: "⥞", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 952, Reference: "MO.WIDEREL"},
	{Operator: "⥟", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 953, Reference: "MO.WIDEREL"},
	{Operator: "⥠", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 954, Reference: "MO.RELSTRETCH"},
	{Operator: "⥡", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 955, Reference: "MO.RELSTRETCH"},
	{Operator: "⥢", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 956, Reference: "MO.RELACCENT"},
	{Operator: "⥣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 957, Reference: "MO.REL"},
	{Operator: "⥤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 958, Reference: "MO.RELACCENT"},
	{Operator: "⥥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 959, Reference: "MO.REL"},
	{Operator: "⥦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 960, Reference: "MO.RELACCENT"},
	{Operator: "⥧", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 961, Reference: "MO.RELACCENT"},
	{Operator: "⥨", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 962, Reference: "MO.RELACCENT"},
	{Operator: "⥩", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 963, Reference: "MO.RELACCENT"},
	{Operator: "⥪", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 964, Reference: "MO.RELACCENT"},
	{Operator: "⥫", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 965, Reference: "MO.RELACCENT"},
	{Operator: "⥬", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 966, Reference: "MO.RELACCENT"},
	{Operator: "⥭", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 967, Reference: "MO.RELACCENT"},
	{Operator: "⥮", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 968, Reference: "MO.RELSTRETCH"},
	{Operator: "⥯", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 969, Reference: "MO.RELSTRETCH"},
	{Operator: "⥰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 970, Reference: "MO.RELACCENT"},
	{Operator: "⥱", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 971, Reference: "MO.RELACCENT"},
	{Operator: "⥲", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 972, Reference: "MO.RELACCENT"},
	{Operator: "⥳", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 973, Reference: "MO.RELACCENT"},
	{Operator: "⥴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 974, Reference: "MO.RELACCENT"},
	{Operator: "⥵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 975, Reference: "MO.RELACCENT"},
	{Operator: "⥶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 976, Reference: "MO.RELACCENT"},
	{Operator: "⥷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 977, Reference: "MO.RELACCENT"},
	{Operator: "⥸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 978, Reference: "MO.RELACCENT"},
	{Operator: "⥹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 979, Reference: "MO.RELACCENT"},
	{Operator: "⥺", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 980, Reference: "MO.RELACCENT"},
	{Operator: "⥻", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 981, Reference: "MO.RELACCENT"},
	{Operator: "⥼", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 982, Reference: "MO.RELACCENT"},
	{Operator: "⥽", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}}}, SourceLine: 983, Reference: "MO.RELACCENT"},
	{Operator: "⥾", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 984, Reference: "MO.REL"},
	{Operator: "⥿", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 985, Reference: "MO.REL"},
	{Operator: "⦁", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 986, Reference: "MO.BIN3"},
	{Operator: "⦂", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 987, Reference: "MO.BIN3"},
	{Operator: "⦙", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 988, Reference: "MO.BIN3"},
	{Operator: "⦚", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 989, Reference: "MO.BIN3"},
	{Operator: "⦛", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 990, Reference: "MO.BIN3"},
	{Operator: "⦜", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 991, Reference: "MO.BIN3"},
	{Operator: "⦝", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 992, Reference: "MO.BIN3"},
	{Operator: "⦞", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 993, Reference: "MO.BIN3"},
	{Operator: "⦟", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 994, Reference: "MO.BIN3"},
	{Operator: "⦠", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 995, Reference: "MO.BIN3"},
	{Operator: "⦡", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 996, Reference: "MO.BIN3"},
	{Operator: "⦢", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 997, Reference: "MO.BIN3"},
	{Operator: "⦣", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 998, Reference: "MO.BIN3"},
	{Operator: "⦤", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 999, Reference: "MO.BIN3"},
	{Operator: "⦥", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1000, Reference: "MO.BIN3"},
	{Operator: "⦦", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1001, Reference: "MO.BIN3"},
	{Operator: "⦧", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1002, Reference: "MO.BIN3"},
	{Operator: "⦨", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1003, Reference: "MO.BIN3"},
	{Operator: "⦩", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1004, Reference: "MO.BIN3"},
	{Operator: "⦪", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1005, Reference: "MO.BIN3"},
	{Operator: "⦫", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1006, Reference: "MO.BIN3"},
	{Operator: "⦬", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1007, Reference: "MO.BIN3"},
	{Operator: "⦭", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1008, Reference: "MO.BIN3"},
	{Operator: "⦮", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1009, Reference: "MO.BIN3"},
	{Operator: "⦯", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1010, Reference: "MO.BIN3"},
	{Operator: "⦰", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1011, Reference: "MO.BIN3"},
	{Operator: "⦱", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1012, Reference: "MO.BIN3"},
	{Operator: "⦲", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1013, Reference: "MO.BIN3"},
	{Operator: "⦳", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1014, Reference: "MO.BIN3"},
	{Operator: "⦴", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1015, Reference: "MO.BIN3"},
	{Operator: "⦵", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1016, Reference: "MO.BIN3"},
	{Operator: "⦶", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1017, Reference: "MO.BIN4"},
	{Operator: "⦷", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1018, Reference: "MO.BIN4"},
	{Operator: "⦸", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1019, Reference: "MO.BIN4"},
	{Operator: "⦹", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1020, Reference: "MO.BIN4"},
	{Operator: "⦺", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1021, Reference: "MO.BIN4"},
	{Operator: "⦻", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1022, Reference: "MO.BIN4"},
	{Operator: "⦼", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1023, Reference: "MO.BIN4"},
	{Operator: "⦽", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1024, Reference: "MO.BIN4"},
	{Operator: "⦾", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1025, Reference: "MO.BIN4"},
	{Operator: "⦿", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1026, Reference: "MO.BIN4"},
	{Operator: "⧀", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1027, Reference: "MO.REL"},
	{Operator: "⧁", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1028, Reference: "MO.REL"},
	{Operator: "⧂", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1029, Reference: "MO.BIN3"},
	{Operator: "⧃", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1030, Reference: "MO.BIN3"},
	{Operator: "⧄", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1031, Reference: "MO.BIN4"},
	{Operator: "⧅", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1032, Reference: "MO.BIN4"},
	{Operator: "⧆", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1033, Reference: "MO.BIN4"},
	{Operator: "⧇", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1034, Reference: "MO.BIN4"},
	{Operator: "⧈", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1035, Reference: "MO.BIN4"},
	{Operator: "⧉", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1036, Reference: "MO.BIN3"},
	{Operator: "⧊", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1037, Reference: "MO.BIN3"},
	{Operator: "⧋", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1038, Reference: "MO.BIN3"},
	{Operator: "⧌", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1039, Reference: "MO.BIN3"},
	{Operator: "⧍", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1040, Reference: "MO.BIN3"},
	{Operator: "⧎", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1041, Reference: "MO.REL"},
	{Operator: "⧏", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1042, Reference: "MO.REL"},
	{Operator: "⧏̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1043, Reference: "MO.REL"},
	{Operator: "⧐", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1044, Reference: "MO.REL"},
	{Operator: "⧐̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1045, Reference: "MO.REL"},
	{Operator: "⧑", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1046, Reference: "MO.REL"},
	{Operator: "⧒", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1047, Reference: "MO.REL"},
	{Operator: "⧓", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1048, Reference: "MO.REL"},
	{Operator: "⧔", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1049, Reference: "MO.REL"},
	{Operator: "⧕", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1050, Reference: "MO.REL"},
	{Operator: "⧖", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1051, Reference: "MO.BIN4"},
	{Operator: "⧗", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1052, Reference: "MO.BIN4"},
	{Operator: "⧘", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1053, Reference: "MO.BIN3"},
	{Operator: "⧙", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1054, Reference: "MO.BIN3"},
	{Operator: "⧛", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1055, Reference: "MO.BIN3"},
	{Operator: "⧜", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1056, Reference: "MO.BIN3"},
	{Operator: "⧝", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1057, Reference: "MO.BIN3"},
	{Operator: "⧞", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1058, Reference: "MO.REL"},
	{Operator: "⧟", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1059, Reference: "MO.BIN3"},
	{Operator: "⧠", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1060, Reference: "MO.BIN3"},
	{Operator: "⧡", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1061, Reference: "MO.REL"},
	{Operator: "⧢", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1062, Reference: "MO.BIN4"},
	{Operator: "⧣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1063, Reference: "MO.REL"},
	{Operator: "⧤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1064, Reference: "MO.REL"},
	{Operator: "⧥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1065, Reference: "MO.REL"},
	{Operator: "⧦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1066, Reference: "MO.REL"},
	{Operator: "⧧", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1067, Reference: "MO.BIN3"},
	{Operator: "⧨", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1068, Reference: "MO.BIN3"},
	{Operator: "⧩", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1069, Reference: "MO.BIN3"},
	{Operator: "⧪", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1070, Reference: "MO.BIN3"},
	{Operator: "⧫", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1071, Reference: "MO.BIN3"},
	{Operator: "⧬", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1072, Reference: "MO.BIN3"},
	{Operator: "⧭", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1073, Reference: "MO.BIN3"},
	{Operator: "⧮", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1074, Reference: "MO.BIN3"},
	{Operator: "⧯", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1075, Reference: "MO.BIN3"},
	{Operator: "⧰", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1076, Reference: "MO.BIN3"},
	{Operator: "⧱", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1077, Reference: "MO.BIN3"},
	{Operator: "⧲", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1078, Reference: "MO.BIN3"},
	{Operator: "⧳", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1079, Reference: "MO.BIN3"},
	{Operator: "⧴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1080, Reference: "MO.REL"},
	{Operator: "⧵", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1081, Reference: "MO.BIN4"},
	{Operator: "⧶", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1082, Reference: "MO.BIN4"},
	{Operator: "⧷", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1083, Reference: "MO.BIN4"},
	{Operator: "⧸", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1084, Reference: "MO.BIN3"},
	{Operator: "⧹", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1085, Reference: "MO.BIN3"},
	{Operator: "⧺", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1086, Reference: "MO.BIN3"},
	{Operator: "⧻", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1087, Reference: "MO.BIN3"},
	{Operator: "⧾", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1088, Reference: "MO.BIN4"},
	{Operator: "⧿", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1089, Reference: "MO.BIN4"},
	{Operator: "⨝", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1090, Reference: "MO.BIN3"},
	{Operator: "⨞", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1091, Reference: "MO.BIN3"},
	{Operator: "⨟", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1092, Reference: "MO.BIN3"},
	{Operator: "⨠", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1093, Reference: "MO.BIN3"},
	{Operator: "⨡", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1094, Reference: "MO.BIN3"},
	{Operator: "⨢", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1095, Reference: "MO.BIN4"},
	{Operator: "⨣", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1096, Reference: "MO.BIN4"},
	{Operator: "⨤", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1097, Reference: "MO.BIN4"},
	{Operator: "⨥", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1098, Reference: "MO.BIN4"},
	{Operator: "⨦", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1099, Reference: "MO.BIN4"},
	{Operator: "⨧", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1100, Reference: "MO.BIN4"},
	{Operator: "⨨", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1101, Reference: "MO.BIN4"},
	{Operator: "⨩", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1102, Reference: "MO.BIN4"},
	{Operator: "⨪", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1103, Reference: "MO.BIN4"},
	{Operator: "⨫", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1104, Reference: "MO.BIN4"},
	{Operator: "⨬", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1105, Reference: "MO.BIN4"},
	{Operator: "⨭", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1106, Reference: "MO.BIN4"},
	{Operator: "⨮", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1107, Reference: "MO.BIN4"},
	{Operator: "⨯", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1108, Reference: "MO.BIN4"},
	{Operator: "⨰", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1109, Reference: "MO.BIN4"},
	{Operator: "⨱", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1110, Reference: "MO.BIN4"},
	{Operator: "⨲", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1111, Reference: "MO.BIN4"},
	{Operator: "⨳", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1112, Reference: "MO.BIN4"},
	{Operator: "⨴", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1113, Reference: "MO.BIN4"},
	{Operator: "⨵", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1114, Reference: "MO.BIN4"},
	{Operator: "⨶", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1115, Reference: "MO.BIN4"},
	{Operator: "⨷", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1116, Reference: "MO.BIN4"},
	{Operator: "⨸", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1117, Reference: "MO.BIN4"},
	{Operator: "⨹", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1118, Reference: "MO.BIN4"},
	{Operator: "⨺", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1119, Reference: "MO.BIN4"},
	{Operator: "⨻", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1120, Reference: "MO.BIN4"},
	{Operator: "⨼", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1121, Reference: "MO.BIN4"},
	{Operator: "⨽", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1122, Reference: "MO.BIN4"},
	{Operator: "⨾", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1123, Reference: "MO.BIN4"},
	{Operator: "⨿", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1124, Reference: "MO.BIN4"},
	{Operator: "⩀", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1125, Reference: "MO.BIN4"},
	{Operator: "⩁", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1126, Reference: "MO.BIN4"},
	{Operator: "⩂", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1127, Reference: "MO.BIN4"},
	{Operator: "⩃", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1128, Reference: "MO.BIN4"},
	{Operator: "⩄", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1129, Reference: "MO.BIN4"},
	{Operator: "⩅", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1130, Reference: "MO.BIN4"},
	{Operator: "⩆", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1131, Reference: "MO.BIN4"},
	{Operator: "⩇", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1132, Reference: "MO.BIN4"},
	{Operator: "⩈", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1133, Reference: "MO.BIN4"},
	{Operator: "⩉", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1134, Reference: "MO.BIN4"},
	{Operator: "⩊", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1135, Reference: "MO.BIN4"},
	{Operator: "⩋", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1136, Reference: "MO.BIN4"},
	{Operator: "⩌", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1137, Reference: "MO.BIN4"},
	{Operator: "⩍", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1138, Reference: "MO.BIN4"},
	{Operator: "⩎", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1139, Reference: "MO.BIN4"},
	{Operator: "⩏", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1140, Reference: "MO.BIN4"},
	{Operator: "⩐", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1141, Reference: "MO.BIN4"},
	{Operator: "⩑", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1142, Reference: "MO.BIN4"},
	{Operator: "⩒", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1143, Reference: "MO.BIN4"},
	{Operator: "⩓", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1144, Reference: "MO.BIN4"},
	{Operator: "⩔", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1145, Reference: "MO.BIN4"},
	{Operator: "⩕", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1146, Reference: "MO.BIN4"},
	{Operator: "⩖", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1147, Reference: "MO.BIN4"},
	{Operator: "⩗", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1148, Reference: "MO.BIN4"},
	{Operator: "⩘", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1149, Reference: "MO.BIN4"},
	{Operator: "⩙", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1150, Reference: "MO.REL"},
	{Operator: "⩚", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1151, Reference: "MO.BIN4"},
	{Operator: "⩛", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1152, Reference: "MO.BIN4"},
	{Operator: "⩜", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1153, Reference: "MO.BIN4"},
	{Operator: "⩝", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1154, Reference: "MO.BIN4"},
	{Operator: "⩞", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1155, Reference: "MO.BIN4"},
	{Operator: "⩟", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1156, Reference: "MO.BIN4"},
	{Operator: "⩠", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1157, Reference: "MO.BIN4"},
	{Operator: "⩡", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1158, Reference: "MO.BIN4"},
	{Operator: "⩢", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1159, Reference: "MO.BIN4"},
	{Operator: "⩣", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1160, Reference: "MO.BIN4"},
	{Operator: "⩤", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1161, Reference: "MO.BIN4"},
	{Operator: "⩥", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1162, Reference: "MO.BIN4"},
	{Operator: "⩦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1163, Reference: "MO.REL"},
	{Operator: "⩧", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1164, Reference: "MO.REL"},
	{Operator: "⩨", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1165, Reference: "MO.REL"},
	{Operator: "⩩", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1166, Reference: "MO.REL"},
	{Operator: "⩪", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1167, Reference: "MO.REL"},
	{Operator: "⩫", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1168, Reference: "MO.REL"},
	{Operator: "⩬", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1169, Reference: "MO.REL"},
	{Operator: "⩭", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1170, Reference: "MO.REL"},
	{Operator: "⩮", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1171, Reference: "MO.REL"},
	{Operator: "⩯", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1172, Reference: "MO.REL"},
	{Operator: "⩰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1173, Reference: "MO.REL"},
	{Operator: "⩱", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1174, Reference: "MO.BIN4"},
	{Operator: "⩲", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1175, Reference: "MO.BIN4"},
	{Operator: "⩳", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1176, Reference: "MO.REL"},
	{Operator: "⩴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1177, Reference: "MO.REL"},
	{Operator: "⩵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1178, Reference: "MO.REL"},
	{Operator: "⩶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1179, Reference: "MO.REL"},
	{Operator: "⩷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1180, Reference: "MO.REL"},
	{Operator: "⩸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1181, Reference: "MO.REL"},
	{Operator: "⩹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1182, Reference: "MO.REL"},
	{Operator: "⩺", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1183, Reference: "MO.REL"},
	{Operator: "⩻", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1184, Reference: "MO.REL"},
	{Operator: "⩼", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1185, Reference: "MO.REL"},
	{Operator: "⩽", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1186, Reference: "MO.REL"},
	{Operator: "⩽̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1187, Reference: "MO.REL"},
	{Operator: "⩾", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1188, Reference: "MO.REL"},
	{Operator: "⩾̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1189, Reference: "MO.REL"},
	{Operator: "⩿", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1190, Reference: "MO.REL"},
	{Operator: "⪀", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1191, Reference: "MO.REL"},
	{Operator: "⪁", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1192, Reference: "MO.REL"},
	{Operator: "⪂", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1193, Reference: "MO.REL"},
	{Operator: "⪃", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1194, Reference: "MO.REL"},
	{Operator: "⪄", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1195, Reference: "MO.REL"},
	{Operator: "⪅", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1196, Reference: "MO.REL"},
	{Operator: "⪆", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1197, Reference: "MO.REL"},
	{Operator: "⪇", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1198, Reference: "MO.REL"},
	{Operator: "⪈", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1199, Reference: "MO.REL"},
	{Operator: "⪉", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1200, Reference: "MO.REL"},
	{Operator: "⪊", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1201, Reference: "MO.REL"},
	{Operator: "⪋", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1202, Reference: "MO.REL"},
	{Operator: "⪌", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1203, Reference: "MO.REL"},
	{Operator: "⪍", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1204, Reference: "MO.REL"},
	{Operator: "⪎", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1205, Reference: "MO.REL"},
	{Operator: "⪏", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1206, Reference: "MO.REL"},
	{Operator: "⪐", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1207, Reference: "MO.REL"},
	{Operator: "⪑", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1208, Reference: "MO.REL"},
	{Operator: "⪒", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1209, Reference: "MO.REL"},
	{Operator: "⪓", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1210, Reference: "MO.REL"},
	{Operator: "⪔", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1211, Reference: "MO.REL"},
	{Operator: "⪕", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1212, Reference: "MO.REL"},
	{Operator: "⪖", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1213, Reference: "MO.REL"},
	{Operator: "⪗", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1214, Reference: "MO.REL"},
	{Operator: "⪘", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1215, Reference: "MO.REL"},
	{Operator: "⪙", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1216, Reference: "MO.REL"},
	{Operator: "⪚", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1217, Reference: "MO.REL"},
	{Operator: "⪛", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1218, Reference: "MO.REL"},
	{Operator: "⪜", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1219, Reference: "MO.REL"},
	{Operator: "⪝", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1220, Reference: "MO.REL"},
	{Operator: "⪞", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1221, Reference: "MO.REL"},
	{Operator: "⪟", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1222, Reference: "MO.REL"},
	{Operator: "⪠", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1223, Reference: "MO.REL"},
	{Operator: "⪡", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1224, Reference: "MO.REL"},
	{Operator: "⪡̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1225, Reference: "MO.REL"},
	{Operator: "⪢", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1226, Reference: "MO.REL"},
	{Operator: "⪢̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1227, Reference: "MO.REL"},
	{Operator: "⪣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1228, Reference: "MO.REL"},
	{Operator: "⪤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1229, Reference: "MO.REL"},
	{Operator: "⪥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1230, Reference: "MO.REL"},
	{Operator: "⪦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1231, Reference: "MO.REL"},
	{Operator: "⪧", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1232, Reference: "MO.REL"},
	{Operator: "⪨", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1233, Reference: "MO.REL"},
	{Operator: "⪩", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1234, Reference: "MO.REL"},
	{Operator: "⪪", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1235, Reference: "MO.REL"},
	{Operator: "⪫", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1236, Reference: "MO.REL"},
	{Operator: "⪬", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1237, Reference: "MO.REL"},
	{Operator: "⪭", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1238, Reference: "MO.REL"},
	{Operator: "⪮", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1239, Reference: "MO.REL"},
	{Operator: "⪯", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1240, Reference: "MO.REL"},
	{Operator: "⪯̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1241, Reference: "MO.REL"},
	{Operator: "⪰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1242, Reference: "MO.REL"},
	{Operator: "⪰̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1243, Reference: "MO.REL"},
	{Operator: "⪱", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1244, Reference: "MO.REL"},
	{Operator: "⪲", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1245, Reference: "MO.REL"},
	{Operator: "⪳", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1246, Reference: "MO.REL"},
	{Operator: "⪴", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1247, Reference: "MO.REL"},
	{Operator: "⪵", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1248, Reference: "MO.REL"},
	{Operator: "⪶", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1249, Reference: "MO.REL"},
	{Operator: "⪷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1250, Reference: "MO.REL"},
	{Operator: "⪸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1251, Reference: "MO.REL"},
	{Operator: "⪹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1252, Reference: "MO.REL"},
	{Operator: "⪺", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1253, Reference: "MO.REL"},
	{Operator: "⪻", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1254, Reference: "MO.REL"},
	{Operator: "⪼", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1255, Reference: "MO.REL"},
	{Operator: "⪽", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1256, Reference: "MO.REL"},
	{Operator: "⪾", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1257, Reference: "MO.REL"},
	{Operator: "⪿", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1258, Reference: "MO.REL"},
	{Operator: "⫀", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1259, Reference: "MO.REL"},
	{Operator: "⫁", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1260, Reference: "MO.REL"},
	{Operator: "⫂", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1261, Reference: "MO.REL"},
	{Operator: "⫃", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1262, Reference: "MO.REL"},
	{Operator: "⫄", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1263, Reference: "MO.REL"},
	{Operator: "⫅", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1264, Reference: "MO.REL"},
	{Operator: "⫆", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1265, Reference: "MO.REL"},
	{Operator: "⫇", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1266, Reference: "MO.REL"},
	{Operator: "⫈", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1267, Reference: "MO.REL"},
	{Operator: "⫉", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1268, Reference: "MO.REL"},
	{Operator: "⫊", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1269, Reference: "MO.REL"},
	{Operator: "⫋", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1270, Reference: "MO.REL"},
	{Operator: "⫌", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1271, Reference: "MO.REL"},
	{Operator: "⫍", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1272, Reference: "MO.REL"},
	{Operator: "⫎", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1273, Reference: "MO.REL"},
	{Operator: "⫏", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1274, Reference: "MO.REL"},
	{Operator: "⫐", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1275, Reference: "MO.REL"},
	{Operator: "⫑", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1276, Reference: "MO.REL"},
	{Operator: "⫒", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1277, Reference: "MO.REL"},
	{Operator: "⫓", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1278, Reference: "MO.REL"},
	{Operator: "⫔", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1279, Reference: "MO.REL"},
	{Operator: "⫕", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1280, Reference: "MO.REL"},
	{Operator: "⫖", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1281, Reference: "MO.REL"},
	{Operator: "⫗", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1282, Reference: "MO.REL"},
	{Operator: "⫘", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1283, Reference: "MO.REL"},
	{Operator: "⫙", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1284, Reference: "MO.REL"},
	{Operator: "⫚", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1285, Reference: "MO.REL"},
	{Operator: "⫛", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1286, Reference: "MO.REL"},
	{Operator: "⫝", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1287, Reference: "MO.REL"},
	{Operator: "⫝̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1288, Reference: "MO.REL"},
	{Operator: "⫞", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1289, Reference: "MO.REL"},
	{Operator: "⫟", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1290, Reference: "MO.REL"},
	{Operator: "⫠", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1291, Reference: "MO.REL"},
	{Operator: "⫡", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1292, Reference: "MO.REL"},
	{Operator: "⫢", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1293, Reference: "MO.REL"},
	{Operator: "⫣", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1294, Reference: "MO.REL"},
	{Operator: "⫤", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1295, Reference: "MO.REL"},
	{Operator: "⫥", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1296, Reference: "MO.REL"},
	{Operator: "⫦", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1297, Reference: "MO.REL"},
	{Operator: "⫧", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1298, Reference: "MO.REL"},
	{Operator: "⫨", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1299, Reference: "MO.REL"},
	{Operator: "⫩", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1300, Reference: "MO.REL"},
	{Operator: "⫪", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1301, Reference: "MO.REL"},
	{Operator: "⫫", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1302, Reference: "MO.REL"},
	{Operator: "⫬", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1303, Reference: "MO.REL"},
	{Operator: "⫭", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1304, Reference: "MO.REL"},
	{Operator: "⫮", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1305, Reference: "MO.REL"},
	{Operator: "⫯", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1306, Reference: "MO.REL"},
	{Operator: "⫰", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1307, Reference: "MO.REL"},
	{Operator: "⫱", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1308, Reference: "MO.REL"},
	{Operator: "⫲", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1309, Reference: "MO.REL"},
	{Operator: "⫳", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1310, Reference: "MO.REL"},
	{Operator: "⫴", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1311, Reference: "MO.BIN4"},
	{Operator: "⫵", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1312, Reference: "MO.BIN4"},
	{Operator: "⫶", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1313, Reference: "MO.BIN4"},
	{Operator: "⫷", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1314, Reference: "MO.REL"},
	{Operator: "⫸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1315, Reference: "MO.REL"},
	{Operator: "⫹", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1316, Reference: "MO.REL"},
	{Operator: "⫺", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1317, Reference: "MO.REL"},
	{Operator: "⫻", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1318, Reference: "MO.BIN4"},
	{Operator: "⫽", Definition: mjOperatorDefinition{Lspace: 4, Rspace: 4, TexClass: 2}, SourceLine: 1319, Reference: "MO.BIN4"},
	{Operator: "⫾", Definition: mjOperatorDefinition{Lspace: 3, Rspace: 3, TexClass: 2}, SourceLine: 1320, Reference: "MO.BIN3"},
	{Operator: "⭅", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 1321, Reference: "MO.RELSTRETCH"},
	{Operator: "⭆", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "stretchy", Value: true}}}, SourceLine: 1322, Reference: "MO.RELSTRETCH"},
	{Operator: "〈", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 4, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 1323, Reference: "MO.OPEN"},
	{Operator: "〉", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 5, Properties: mjOperatorProperties{{Name: "fence", Value: true}, {Name: "stretchy", Value: true}, {Name: "symmetric", Value: true}}}, SourceLine: 1324, Reference: "MO.CLOSE"},
	{Operator: "︷", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 1325, Reference: "MO.WIDEACCENT"},
	{Operator: "︸", Definition: mjOperatorDefinition{Lspace: 0, Rspace: 0, TexClass: 0, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 1326, Reference: "MO.WIDEACCENT"},
	{Operator: "⫝̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1339, Reference: "MO.REL"},
}

var mjOperatorDictionaryMutations = []mjOperatorDictionaryMutation{
	{Form: "infix", Operator: "^", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 1333, Reference: "MO.WIDEREL", HadPrevious: true, PreviousDefinition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 0}, PreviousSourceLine: 432, PreviousReference: "MO.ORD11"},
	{Form: "infix", Operator: "_", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3, Properties: mjOperatorProperties{{Name: "accent", Value: true}, {Name: "stretchy", Value: true}}}, SourceLine: 1334, Reference: "MO.WIDEREL", HadPrevious: true, PreviousDefinition: mjOperatorDefinition{Lspace: 1, Rspace: 1, TexClass: 0}, PreviousSourceLine: 433, PreviousReference: "MO.ORD11"},
	{Form: "infix", Operator: "⫝̸", Definition: mjOperatorDefinition{Lspace: 5, Rspace: 5, TexClass: 3}, SourceLine: 1339, Reference: "MO.REL"},
}
